@@ -1,25 +1,38 @@
 <?
-/* Network Autodiscovery
- * Copyright (C) <2004> Javier Szyszlican <javier@szysz.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+/* Network Autodiscovery. This file is part of JFFNMS
+ * Copyright (C) <2004-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
  */
 
-    $jffnms_functions_include="engine";
-    include_once("../conf/config.php");
+    $launcher_function = "discovery_network";
+    $launcher_item_source = "nad_core";
+    $launcher_init = "nad_init";
+    $launcher_child_status ="nad_status";
+    $launcher_status = "show_networks";
+
+    $launcher_param_managed_handler = "nad_params_managed";
+    
+    $refresh_items = true;
+    $refresh_time = 10;
+    
+    $timeout = 60*4;
+    //$launcher_detach = false;
+
+    require ("launcher.inc.php");
+
+//-=-=-=-=-==-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+    function nad_load_ips() {    
+
+	$query_ips = "SELECT ip, type FROM nad_ips WHERE id > 1";
+	$result_ips = db_query ($query_ips) or die ("Query Error - ".db_error());
+    
+	$ips = array();
+	
+	while ($rip = db_fetch_array ($result_ips)) 
+	    $ips[$rip["ip"]] = $rip["type"];
+    
+	return $ips;
+    }
 
     function ip_to_str2 ($ip_ip) {
 	$ip_bin = decbin($ip_ip);
@@ -62,202 +75,75 @@
 	
 	return false;
     }
+
+    function nad_private_net ($ip) {
+	$private_nets = array("10.0.0.0/8", "172.16.0.0/12", "192.168.0.0/16", "127.0.0.0/8", "192.169.0.0/16");
+	
+	foreach ($private_nets as $priv) {
+	    list ($private_net, $private_mask) = explode ("/", $priv);
+	    list ($net) = explode ("/", $ip);
 	    
-    function nad_add_network ($ip, $mask, $deep, $parent_net, $seed_id) {
-
-	if (empty($mask)) { // /24
-	    list($ip, $bitmask) = explode("/",$ip);
-	    $mask = bitsmask_to_mask ($bitmask);
-	}
-    
-	    $ip_bit = str_to_ip($ip);
-	    $mask_bit = str_to_ip($mask);
-
-	    $net_bit = $ip_bit & $mask_bit;
-	    $net = ip_to_str2 ($net_bit);
-
-	    if ($net != "127.0.0.0") {
-		$oper_status = 0;
-
-		$mask_prefix = ip_to_bitsmask ($mask_bit);
-	    
-		if ($mask_prefix < 24) $mask_prefix = 24;
-		
-		if ($mask_prefix == 31) $mask_prefix = 32;
-	
-		if (($mask_prefix == 32) && ($parent_net!=1)) $oper_status = 3;
-	    
-		$aux ="$net/$mask_prefix";
-	
-		$networks = nad_load_networks();
-		
-		/*
-		logger ("***** Trying to add Path to network $aux ".
-		    (isset($networks["aux"])?"(Alredy added as ".$networks["aux"]["id"].") ":"").
-		    "via NET_ID $parent_net, Deep $deep\n");
-		*/
-		
-		if (!isset($networks[$aux]))
-		    return db_insert("nad_networks",array("network"=>$aux, "deep"=>$deep, "parent"=>$parent_net, 
-			"oper_status"=>$oper_status, "seed"=>$seed_id, "oper_status_changed"=>time()));
-		else
-		    return $networks[$aux]["id"];	// return the network id
-	    }
-    }
-
-    function nad_add_ip ($ip, $dns = "", $host = 1, $network = 1, $type = 1) {
-	$data = compact("ip","dns","host","type","network");
-	return db_insert ("nad_ips",$data);
-    }
-
-    function nad_update_ip ($ip_id, $dns, $host, $network, $type = 1) {
-	$data = compact("ip","dns","host","type","network");
-	return db_update ("nad_ips",$ip_id, $data);
-    }
-
-    function nad_del_ip ($ip_id) {
-	return db_delete ("nad_ips",$ip_id);
-    }
-
-    function nad_add_host () {
-	return db_insert ("nad_hosts",array());
-    }	
-
-    function nad_update_host ($host_id, $host_data) {
-	return db_update("nad_hosts", $host_id, $host_data);
-    }
-
-    function nad_load_seeds ($networks) {
-	$seeds_query = "SELECT id, seeds, refresh FROM zones where id > 1 and seeds != '' and admin_status = 1";
-	$seeds_result = db_query ($seeds_query) or die ("Query Error - ".db_error());
-
-	$something_changed = false;
-	while ($rseed = db_fetch_array($seeds_result)) { 		//read each seed
-	    $seeds = explode (",",$rseed["seeds"]);
-
-	    foreach ($seeds as $seed) {				//foreach seed
-		$seed = trim($seed);
-
-		$total_seeds++;
-		
-		if (!isset($networks[$seed])) {			//if its not already in the networks list
-		    nad_add_network($seed,"",1,1,$rseed["id"]);	//its new, then add it to the DB.
-		    $something_changed = true;			//tell the caller that something has changed
-		} 
-	    }
-	}
-
-	if ($total_seeds==0) $something_changed = true;
-	
-	return $something_changed;	
-    }
-
-    function nad_load_networks($network="") {    
-
-	$query_networks = "
-	    SELECT nad_networks.*, zones.max_deep, zones.communities, zones.admin_status, zones.refresh 
-	    FROM nad_networks, zones
-	    WHERE nad_networks.id > 1 AND nad_networks.seed = zones.id ".(!empty($network)?" AND network = '$network'":"");
-	$result_networks = db_query ($query_networks) or die ("Query Error - ".db_error());
-    
-	$networks = array();
-	
-	while ($rnet = db_fetch_array ($result_networks))
-	    $networks[$rnet["network"]] = array ("deep"=>$rnet["deep"], 
-		"oper_status"=>$rnet["oper_status"], "admin_status"=>$rnet["admin_status"], "parent"=>$rnet["parent"],
-		"id"=>$rnet["id"], "communities"=>explode(",",$rnet["communities"]), "max_deep"=>$rnet["max_deep"],
-		"seed"=>$rnet["seed"], "oper_status_changed"=>$rnet["oper_status_changed"], "refresh"=>$rnet["refresh"]);
-
-	return $networks;
-    }
-    
-    function nad_network_status($net_id, $status) {
-	return db_update("nad_networks",$net_id, array("oper_status"=>$status, "oper_status_changed"=>time()));
-    }
-
-    function nad_load_ips() {    
-
-	$query_ips = "SELECT ip, type FROM nad_ips WHERE id > 1";
-	$result_ips = db_query ($query_ips) or die ("Query Error - ".db_error());
-    
-	$ips = array();
-	
-	while ($rip = db_fetch_array ($result_ips)) 
-	    $ips[$rip["ip"]] = $rip["type"];
-    
-	return $ips;
-    }
-    
-    function nad_cleanup_network ($net_id) {
-	$hosts_query = "SELECT nad_hosts.id FROM nad_hosts, nad_ips 
-	    WHERE nad_ips.host = nad_hosts.id AND nad_ips.network = $net_id";
-	$hosts_result = db_query ($hosts_query) or die ("Query Error - ".db_error());
-
-	$hosts = array();
-	while ($rhost = db_fetch_array($hosts_result))
-	    $hosts[]=$rhost["id"];
-    
-	if (count($hosts) > 0) {
-	    $hosts_query = "DELETE FROM nad_hosts WHERE id = ".join(" OR id = ",$hosts);
-	    $hosts_result = db_query ($hosts_query) or die ("Query Error - Hosts Delete - ".db_error());
+	    if (ip_same_network($net, $private_net, bitsmask_to_mask($private_mask)))
+		return true;
 	}
 	
-	$ips_query = "DELETE FROM nad_ips WHERE network = $net_id";
-	$ips_result = db_query ($ips_query) or die ("Query Error - IPS Delete - ".db_error());
-	
-	return ($ips_result && $hosts_result);
-    }
-    
-    function nad_cleanup () {
-	$queries[]="DELETE FROM nad_networks WHERE id > 1";
-	$queries[]="DELETE FROM nad_hosts WHERE id > 1";
-	$queries[]="DELETE FROM nad_ips WHERE id >1";
-	$queries[]="UPDATE nad_networks SET oper_status = 0 WHERE id > 1";
-	
-	foreach ($queries as $query)
-	    $result = db_query($query) or die ("Query Error - Cleanup - ".db_error());
-
-	db_repair("nad_networks");
-	db_repair("nad_hosts");
-	db_repair("nad_ips");
-	
-	return $result;
+	return false;
     }
 
+    function nmap_pipe ($target, $data) {
+    
+	if (!is_array($data[$target])) {
+    	    $data[$target]["res"] = proc_open(
+		get_config_option("nmap_executable"). " -sP -PB --randomize_hosts -T3 -iL - -oG -",
+                array(0=>array("pipe","r"), 1=>array("pipe","w"), 2=>array("pipe","r")), $data[$target]["pipes"]);
 
-    function discovery_network ($network, $net_data) {
-    
-	$nmap = get_config_option("nmap_executable");
-        $temp = get_config_option("engine_temp_path");
-    
+	    fwrite($data[$target]["pipes"][0], $target."\n");
+	    fclose($data[$target]["pipes"][0]);
+	}
+	
+	if (false !== ($ret = fgets($data[$target]["pipes"][1]))) 
+	    if ($ret != "# Nmap run completed")
+		return rtrim($ret,"\n");
+
+	return false;
+    }
+
+    function discovery_network ($network, $output = true) {
+
+	$nad_time_start = time();
+	$hosts_up = 0;
+	$hosts_unique = 0;
+	
+	$net_data = current(nad_load_networks($network));
+	
+	if (!$output) ob_start();
+	
 	logger ("N ".str_pad($net_data["id"], 4)." : ".
-		"Scanning Network $network, deep ".$net_data["deep"]."\n");	
+		"Scanning Network ".$network.", deep ".$net_data["deep"]."\n");	
 	
-	nad_network_status ($net_data["id"],2); //Started
-    
-	$file = "$temp/".uniqid("na").".dat";
-	$aux = "$nmap -sP -PE --randomize_hosts -T4 -oG $file ".str_replace("/32","",$network);
-	exec ($aux,$a,$b); 
-    
-	$data = file ($file);
-	unlink ($file);
-	
-	foreach ($data as $line)
-	    if (preg_match ("/Host\: (.*).*\((.*)\).*Status\: (.*)/",trim($line),$parts)) {
+	nad_network_status ($net_data["id"], 2); //Running
+
+	while ($line = nmap_pipe($network, &$nmap_data)) 
+	    if (preg_match ("/Host\: (.*) \((.*)\).*Status\: (.*)/", $line ,$parts)) {
+
+		if (!$output) launcher_heartbeat(); 
 
 		$host_ip = trim($parts[1]);
 		$host_name = $parts[2];
 		    
-		$log =  "N ".str_pad($net_data["id"], 4)." : ".
-			"Scanning Host $host_ip";
+		$log =  "N ".str_pad($net_data["id"], 4)." : Scanning Host ".$host_ip;
 		
 		$host_ip_parts = explode(".",$host_ip);
 		
+				
 		if (($host_ip_parts[3]!=0) && ($host_ip_parts[3]!=255)) {
 		    if ($parts[3]=="Up") {
+			$hosts_up++;
+			
 			if (array_key_exists($host_ip, nad_load_ips())==false) {
 
 			    $host_id = nad_add_host ();
+			    $hosts_unique++;
 
 			    logger ($log." Responded to Ping added as H $host_id\n");
 		
@@ -266,7 +152,7 @@
 			    $ips_found = discovery_host ($host_id, $host_ip, $net_data["communities"], $net_data, $ip_id);
 		    
 			    if (!$ips_found)
-				nad_update_ip ($ip_id, $host_name, $host_id, $net_data["id"], $net_data["seed"]);
+				nad_update_ip ($ip_id, $host_name, $host_id, $net_data["id"]);
 			
 			} else
 			    logger ($log." Already Added\n");
@@ -275,8 +161,12 @@
 		} else
 		    logger ($log." Invalid\n");
 	    }
+
+	nad_network_status ($net_data["id"], 3); //done
 	
-	nad_network_status ($net_data["id"],3); //done
+	ob_end_clean();
+	
+	return array("OK", $hosts_up, $hosts_unique, time()-$nad_time_start);
     }
 
     function discovery_host ($host_id, $host_ip, $communities, $net, $host_ip_id) {
@@ -292,6 +182,8 @@
 	$intstatus_oid = ".1.3.6.1.2.1.2.2.1.8";
 
 	$invalid_ips = array("127.0.0.1","0.0.0.0");
+	if (!is_array($communities)) $communities = array();
+	
 	$result = false;
 
 	while ((list (, $comm) = each ($communities)) && (!$snmp_name))
@@ -338,7 +230,7 @@
 			
 			//$if_status = 1;
 			if ($if_status == 1) { // Its UP
-			
+			    unset ($if_type);
 			    list(,$if_type) = split("[()]",snmp_get($host_ip, $comm, $inttype_oid.".".$if_index));
 			    
 			    $host_ips[$aux_ip]["mask"] = $aux_mask;
@@ -346,8 +238,8 @@
 			
 			} else {	// Its Down
 			
-			    nad_del_ip($host_ips[$aux_ip]["ip_id"]); // Delete the IP
-			    unset ($host_ips[$aux_ip]);
+			    nad_del_ip($host_ips[$aux_ip]["ip_id"]);  	// Delete the IP from the DB
+			    unset ($host_ips[$aux_ip]);			// remove it from the list used to add networks
 			}
 		    }
 		    unset ($snmp_mask_data);
@@ -390,7 +282,7 @@
 			if ($ipd["dns"]==$ip) unset ($ipd["dns"]); 	// Do not add the DNS if this IP doesn't have a reverse
 
 			logger ($log." Has IP $ip - ".$ipd["mask"]." - ".$ipd["dns"]."\n");
-
+			
 			$new_net_id = nad_add_network ($ip, $ipd["mask"], $net["deep"]+1, $net["id"], $net["seed"]);
 
 			if (!is_numeric($new_net_id)) $new_net_id = $net["id"];
@@ -399,7 +291,6 @@
 
 			$result = true; //we found some ip's
 		    }
-		
 		}	
 
 		// Get Description
@@ -407,6 +298,7 @@
 
 		// Findout if the Host has IP Forwarding (Router) Enabled
 		list(,$host_forwarding) = split("[()]",snmp_get($host_ip, $comm, $ipforwarding_oid));
+	
 		if ($host_forwarding==2) $host_forwarding = 0;
 		
 		// Update Host information
@@ -417,136 +309,280 @@
 	return $result;
     }
 
-    function reload_networks ($network = "", $show = true) {
+
+    function nad_add_network ($ip, $mask, $deep, $parent_net, $seed_id, $id=NULL) {
+
+	if (empty($mask)) { // /24
+	    list($ip, $bitmask) = explode("/",$ip);
+	    $mask = bitsmask_to_mask ($bitmask);
+	}
+    
+	    $ip_bit = str_to_ip($ip);
+	    $mask_bit = str_to_ip($mask);
+
+	    $net_bit = $ip_bit & $mask_bit;
+	    $net = ip_to_str2 ($net_bit);
+
+	    if ($net != "127.0.0.0") {
+		$oper_status = 0;
+
+		$mask_prefix = ip_to_bitsmask ($mask_bit);
+	    
+		if ($mask_prefix < 22) $mask_prefix = 22;
+		
+		if ($mask_prefix == 31) $mask_prefix = 32;
+	
+		if (($mask_prefix == 32) && ($parent_net!=1)) $oper_status = 3;
+	    
+		$aux ="$net/$mask_prefix";
+	
+		$networks = nad_load_networks();
+		
+		/*
+		logger ("***** Trying to add Path to network $aux ".
+		    (isset($networks["aux"])?"(Alredy added as ".$networks["aux"]["id"].") ":"").
+		    "via NET_ID $parent_net, Deep $deep\n");
+		*/
+		
+		if (!isset($networks[$aux]))
+		    return db_insert("nad_networks",array("network"=>$aux, "deep"=>$deep, "parent"=>$parent_net, 
+			"oper_status"=>$oper_status, "seed"=>$seed_id, "oper_status_changed"=>time(), "id"=>$id));
+		else
+		    return $networks[$aux]["id"];	// return the network id
+	    }
+    }
+
+    function nad_load_networks($network="") {    
+
+	$query_networks = "
+	    SELECT nad_networks.*, zones.max_deep, zones.communities, zones.admin_status, zones.refresh, zones.allow_private
+	    FROM nad_networks, zones
+	    WHERE nad_networks.id > 1 AND nad_networks.seed = zones.id ".(!empty($network)?" AND network = '$network'":"");
+	$result_networks = db_query ($query_networks) or die ("Query Error - ".db_error());
+    
+	$networks = array();
+	
+	while ($rnet = db_fetch_array ($result_networks))
+	    $networks[$rnet["network"]] = array ("deep"=>$rnet["deep"], 
+		"oper_status"=>$rnet["oper_status"], "admin_status"=>$rnet["admin_status"], "parent"=>$rnet["parent"],
+		"id"=>$rnet["id"], "communities"=>explode(",",$rnet["communities"]), "max_deep"=>$rnet["max_deep"],
+		"seed"=>$rnet["seed"], "oper_status_changed"=>$rnet["oper_status_changed"], "refresh"=>$rnet["refresh"],
+		"allow_private"=>$rnet["allow_private"]);
+
+	return $networks;
+    }
+
+    function nad_add_ip ($ip, $dns = "", $host = 1, $network = 1, $type = 1) {
+	$data = compact("ip","dns","host","type","network");
+	return db_insert ("nad_ips",$data);
+    }
+
+    function nad_update_ip ($ip_id, $dns, $host, $network, $type = 1) {
+	$data = compact("ip","dns","host","type","network");
+	return db_update ("nad_ips",$ip_id, $data);
+    }
+
+    function nad_del_ip ($ip_id) {
+	return db_delete ("nad_ips",$ip_id);
+    }
+
+    function nad_add_host () {
+	return db_insert ("nad_hosts",array("date_added"=>time()));
+    }	
+
+    function nad_update_host ($host_id, $host_data) {
+	return db_update("nad_hosts", $host_id, $host_data);
+    }
+
+    function nad_network_status($net_id, $status) {
+	return db_update("nad_networks",$net_id, array("oper_status"=>$status, "oper_status_changed"=>time()));
+    }
+
+    function nad_cleanup_network ($net_id) {
+	$hosts_query = "
+	    SELECT nad_hosts.id 
+	    FROM nad_hosts, nad_ips 
+	    WHERE nad_ips.host = nad_hosts.id AND nad_ips.network = ".$net_id;
+	$hosts_result = db_query ($hosts_query) or die ("Query Error - ".db_error());
+
+	$hosts = array();
+	while ($rhost = db_fetch_array($hosts_result))
+	    $hosts[]=$rhost["id"];
+    
+	if (count($hosts) > 0) {
+	    $hosts_query = "DELETE FROM nad_hosts WHERE id = ".join(" OR id = ",$hosts);
+	    $hosts_result = db_query ($hosts_query) or die ("Query Error - Hosts Delete - ".db_error());
+	}
+	
+	$ips_query = "DELETE FROM nad_ips WHERE network = ".$net_id;
+	$ips_result = db_query ($ips_query) or die ("Query Error - IPs Delete - ".db_error());
+
+	$net_query = "DELETE FROM nad_networks WHERE id = ".$net_id;
+	$net_result = db_query ($net_query) or die ("Query Error - Net Delete - ".db_error());
+
+	db_repair("nad_networks");
+	db_repair("nad_hosts");
+	db_repair("nad_ips");
+
+	return ($ips_result && $hosts_result && $net_query);
+    }
+
+    function nad_params_managed($params) {
+	$params[1] = false;
+	return $params;
+    }
+
+    function nad_load_seeds ($networks = array()) {
+
+	$seeds_query = "SELECT id, seeds, refresh FROM zones where id > 1 and seeds != '' and admin_status = 1";
+	$seeds_result = db_query ($seeds_query) or die ("Query Error - ".db_error());
+
+	$something_changed = false;
+
+	while ($rseed = db_fetch_array($seeds_result)) { 	//read each seed
+	    $seeds = explode (",",$rseed["seeds"]);
+
+	    foreach ($seeds as $seed) {				//foreach seed
+		$seed = trim($seed);
+
+		$total_seeds++;
+		
+		if (!isset($networks[$seed])) {			//if its not already in the networks list
+		    nad_add_network($seed,"",1,1,$rseed["id"]);	//its new, then add it to the DB.
+		    $something_changed = true;			//tell the caller that something has changed
+		} 
+	    }
+	}
+
+	if ($total_seeds==0) $something_changed = true;
+	
+	return $something_changed;	
+    }
+
+    function nad_init () {
+
+	db_repair("nad_networks");
+	db_repair("nad_hosts");
+	db_repair("nad_ips");
+
+	nad_load_seeds(nad_load_networks());
+	
+	return true;
+    }
+
+    function nad_status ($child, $result) {
+    
+	list (,$status, $hosts_total, $hosts_new, $time) = explode (" ", $result);
+	
+	$ok = $status=="OK"?true:false;
+	
+	logger (
+	    "NAD ".$child["pid"]." ".
+	    ($ok
+	    ?"finished discovering network ".$child["item"]." in ".time_hms($time).", Hosts $hosts_new/$hosts_total"
+	    :"failed when discovering network ".$child["item"].": ".$result)
+	.".\n");
+
+	return $ok;
+    }
+
+    function show_networks () {
+    
 	$network_admin_status=array(0=>"stopped","started");
 
-	$network_oper_status=array(0=>"pending",1=>"starting",2=>"running",3=>"done", 4=>"other path");
+	$network_oper_status=array(0=>"pending",1=>"starting",2=>"running",3=>"done", 4=>"other path", 5=>"error");
 	
-	$networks = nad_load_networks($network);    
+	$networks = nad_load_networks();
+	
+	logger ("Number      Network          Deep/Max         Status       Changed           IDs\n");
 
-	if (empty($network) && $show) {
-	    logger ("Number      Network          Deep/Max         Status       Changed           IDs\n");
-	    foreach ($networks as $network=>$net_data)
-		logger (
+	foreach ($networks as $network=>$net_data) {
+	    logger (
 		str_pad(++$i,5," ",STR_PAD_LEFT).
 		"\t".str_pad($network,18).
 		"\t".str_pad($net_data["deep"]."/".$net_data["max_deep"],7).
 		str_pad($network_admin_status[$net_data["admin_status"]].
 		"/".$network_oper_status[$net_data["oper_status"]],16).
-		" ".str_pad((time()-$net_data["oper_status_changed"])." secs ago",15).
+		" ".str_pad((time()-$net_data["oper_status_changed"])." secs ago",15," ",STR_PAD_LEFT).
 		"\tNID ".str_pad($net_data["id"],5).
 		"PID ".$net_data["parent"].
 		"\n");
-
-	    logger(str_repeat("=-",45)."\n");
-	    reset($networks);
 	}
-	
-	return $networks;	
+
+	logger(str_repeat("=-",45)."\n");
     }
     
-    list (, $start_network) = $_SERVER["argv"];
+    function nad_core () {
+    	global $pending_items, $timeout;
 
-    if (is_process_running(NULL,2)) 
-	die ("Process Already Running.\n");
+	$pending = array();
+	$nets = nad_load_networks();
 
-    if ($start_network=="show") {
-	$networks = reload_networks();
-	nad_load_seeds($networks);
-	reload_networks();
-	die();
-    }	
+	while (list($network, $net_data) = each ($nets)) {
+
+	    if (($net_data["admin_status"]==1) &&					// admin up 
+		($net_data["deep"] <= $net_data["max_deep"]))	{			// deep is less than max deep
+
+		// First Start
+		if ($net_data["oper_status"]==0)				// oper status pending
+		    if (($net_data["allow_private"]==1) || !nad_private_net($network)) {// seed allows private or this IP is not private
+
+	    	        nad_network_status ($net_data["id"], 1); 			// mark it as Starting
     
-    $nad_time = time_usec();
+			logger("Changing Network ".$network." status to Starting.\n");
 
-    if (!isset($start_network)) {
+		        $pending[]=$network;
 
-	$max_running = 15;
-	$running = 0;
-	$retry_seconds = 60;
-	
-	nad_cleanup();
+		    } else {								//Private IP
 
-	if (nad_load_seeds ($networks)) 			//if there was something changed with the seeds
-	    $networks = reload_networks($start_network,true);	//reload the networks
+			nad_network_status ($net_data["id"], 5); 			// mark it as error
+		        logger("Discarded Network $network, because its private space.\n");
+		    }	
 
-	do {
-	    $started = false;
+		// Hanged Starting
+		if (($net_data["oper_status"] == 1) && 					// oper starting
+		    (time()-$net_data["oper_status_changed"] > $timeout)) {		// it didn't start correctly 
 
-	    reset ($networks);
+		    nad_network_status ($net_data["id"], 0); 				// mark it as Pending
+		    logger("Changed Network $network to Pending, because it was hanged starting\n");
+		} 
 
-	    while ((list ($network, $net_data) = each ($networks)) && !$started) {
+		// Hanged Running
+		if (($net_data["oper_status"] == 2) && 					// if its Running
+		    !isset($pending_items[$network])) {					// and its not in the pending list
 		
-		if (($running < $max_running) && 			//we've less than max already running
-		    ($net_data["admin_status"]==1) && 			//its admin started
-		    ($net_data["oper_status"]==0) && 			//its oper pending
-		    ($net_data["deep"] <= $net_data["max_deep"])) {	//deep is less than max deep
-
-			spawn (NULL,$network); 				//start it
-		        nad_network_status ($net_data["id"],1); 	//mark it as Starting
-			sleep(1);					//sleep
-			$started = true;				//mark as we started something
-		    }
-	    }
-	    
-	    $networks = reload_networks();
-	    $done = true;
-	    $something_changed = false;
-	    $running = 0;
-	
-	    while (list ($network, $net_data) = each ($networks))
-		if (($net_data["admin_status"]==1) && 			//if its admin started
-		    ($net_data["deep"] <= $net_data["max_deep"])) {	//deep is less than max deep
-		    
-		    if ($net_data["oper_status"] < 3) 			//if its not done yet
-			$done = false;					//we haven't finished
-		    
-		    if (($net_data["oper_status"] > 0) && 		//if its started and
-			($net_data["oper_status"] < 3))			//not done
-			$running++;					//count it as running
-		
-		    if (($net_data["oper_status"] == 1) && 					// if its Starting
-			(time()-$net_data["oper_status_changed"] > $retry_seconds)) {		// and has not started for N seconds
-		    	    nad_network_status ($net_data["id"],0); 				// mark it as pending
-			    $something_changed = true;
-		    }
-
-		    if (($net_data["oper_status"] == 2) && 					// if its Running
-			(time()-$net_data["oper_status_changed"] > ($retry_seconds*4))) {	// and has not finished for Retry*4 seconds
-		    	    nad_network_status ($net_data["id"],0); 				// mark it as pending
-			    //nad_cleanup_network ($net_data["id"]);				// Cleanup this network data
-			    $something_changed = true;
-		    }
-
-		    if (($net_data["oper_status"] == 3) &&					// if its Done
-			(time()-$net_data["oper_status_changed"] > $net_data["refresh"])) {	// and has been for more time than refresh
-			    nad_network_status ($net_data["id"], 0);				// Mark it as Pending
-			    nad_cleanup_network ($net_data["id"]);				// Cleanup this network data
-			    $something_changed = true;
-		    }
+		    nad_network_status ($net_data["id"], 5); 				// mark it as error
+		    logger("Changed Network $network to Error, because it was hanged running\n");
 		}
 
-	    if ($something_changed) { 
-		$networks = reload_networks($start_network);	//reload the networks
-		$done = false;					// we still have job to do
-	    }
-		
-	    if (!$done && !$started && !$something_changed) 	//if we're not done, and we haven't started anything, and nothing has changed
-		sleep(10);					//sleep 10
+		// Refresh
+		if (($net_data["oper_status"] >= 3) && 					// oper done or error
+		    (time()-$net_data["oper_status_changed"] > $net_data["refresh"])) {	// and has been for more time than refresh
 	
-	} while (!$done);
-    
-	$nad_time = round(time_usec_diff($nad_time)/1000);
-        logger("Total Network Autodiscovery took $nad_time sec.\n");
+		    logger ("Cleaning Network ".$network."\n");
+		    nad_cleanup_network ($net_data["id"]);				// Cleanup this network data
+		
+		    logger("Reloading Network ".$network."\n");
+		    nad_add_network ($network, "", $net_data["deep"], $net_data["parent"], $net_data["seed"], $net_data["id"]);
 
-    } else { // Discover this specific network
+		    $net_data["oper_status"] = 0;					// do not count as done now
+		}
+	    } else 								// Admin Down or Max Deep	
+		if ($net_data["oper_status"] != 5) {				// Not already Error
 
-	$networks = reload_networks($start_network,false);
+    		    nad_network_status ($net_data["id"], 5); 			// mark it as error
+		    logger("Discarded Network $network, because its admin/down or out of reach because of deep.\n");
+		}	
+	
+	    // Done or Error
+	    if (($net_data["oper_status"] == 3) || ($net_data["oper_status"] == 5))	// if its Done or Error
+		$done_networks++;
+	}
+	
+	if ((count($pending)==0) && ($done_networks==count($nets)))			// Nothing else to do
+	    $GLOBALS["refresh_items"] = false;						// stop refreshing the list/exit
 
-	discovery_network ($start_network, $networks[$start_network]);
-
-	$nad_time = round(time_usec_diff($nad_time)/1000);
-
-    	logger("N ".str_pad($networks[$start_network]["id"], 4)." : Network $start_network Autodiscovery took $nad_time sec.\n");
+	return $pending; 
     }
+
 ?>
