@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     //CISCO-CONFIG-COPY-MIB Configuration Downloader Implementation
     //from: http://www.cisco.com/warp/public/477/SNMP/copy_configs_snmp.shtml
     //	waiting(1), running(2), successful(3), failed(4)
@@ -7,16 +11,16 @@
 
 	if ($ip && $rwcommunity && $server && $filename) {
 	    $oid = ".1.3.6.1.4.1.9.9.96.1.1.1.1";
-	    $result = snmpset($ip,$rwcommunity,"$oid.14.999","i",6); //destroy
+	    $result = snmp_set($ip,$rwcommunity,"$oid.14.999","i",6); //destroy
 
 	    if ($result==true) {
-		snmpset($ip,$rwcommunity,"$oid.14.999","i","5"); //create and wait
-		snmpset($ip,$rwcommunity,"$oid.2.999","i","1"); //tftp
-		snmpset($ip,$rwcommunity,"$oid.3.999","i","4"); //running
-		snmpset($ip,$rwcommunity,"$oid.4.999","i","1"); //network
-		snmpset($ip,$rwcommunity,"$oid.5.999","a",$server); //server
-		snmpset($ip,$rwcommunity,"$oid.6.999","s",$filename); //filename
-		snmpset($ip,$rwcommunity,"$oid.14.999","i","1"); //activate
+		snmp_set($ip,$rwcommunity,"$oid.14.999","i","5"); //create and wait
+		snmp_set($ip,$rwcommunity,"$oid.2.999","i","1"); //tftp
+		snmp_set($ip,$rwcommunity,"$oid.3.999","i","4"); //running
+		snmp_set($ip,$rwcommunity,"$oid.4.999","i","1"); //network
+		snmp_set($ip,$rwcommunity,"$oid.5.999","a",$server); //server
+		snmp_set($ip,$rwcommunity,"$oid.6.999","s",$filename); //filename
+		snmp_set($ip,$rwcommunity,"$oid.14.999","i","1"); //activate
 	    
 		sleep (2);
 	    
