@@ -1,11 +1,16 @@
 <? 
-    //Written by Robert Bogdon
-    //Modifications by Javier Szyszlican
+/* This file is part of JFFNMS
+ * Copyright (C) <2002> Robert Bogdon 
+ * Copyright (C) <2002-2005> Modifications by Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
 
     function discovery_host_information ($ip,$rocommunity,$hostid,$param) { 
 
-	if (strpos($param,",") > 1) $systems = explode(",",$param);
-	else $systems[]=$param;
+	if (strpos($param,",") > 1) 
+	    $systems = explode(",",$param);
+	else 
+	    $systems[]=$param;
 
 	if ($ip && $hostid && $rocommunity)
     	    $system_oid = snmp_walk($ip, $rocommunity, ".1.3.6.1.2.1.1.2"); // system.sysObjectID
