@@ -1,20 +1,32 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     function discovery_snmp_interfaces($ip,$rocommunity,$hostid,$param) {
 
 	    $ifAux = array();
 	    $snmp_interfaces = array();
 
-	    if ((ip2long($ip)!==-1) && !empty($hostid) && !empty($rocommunity))  
-		$ifIndex 	= snmp_walk($ip,$rocommunity,".1.3.6.1.2.1.2.2.1.1");
+	    list($host_ip) = explode(":",$ip); 		//remove :port from IP
+	    $host_ip = gethostbyname ($host_ip);	//try to resolve it, this is just to check there is an IP
+
+	    if ((ip2long($host_ip)!==-1) && !empty($hostid) && !empty($rocommunity))  
+		$ifIndex 	= snmp_walk($ip, $rocommunity, ".1.3.6.1.2.1.2.2.1.1");
 
 	    if (is_array($ifIndex) && (count($ifIndex) > 0)) {
 		
-		// Check if its CatOS
+		// Exceptions
 		include_once(jffnms_shared("catos"));	//Load the CatOS Functions
+		include_once(jffnms_shared("webos"));	//Load the WebOS Functions
 
-		if (is_catos($ip, $rocommunity)) 
-		    list ($ifDescr_oid, $ifAlias) = catos_info($ip, $rocommunity); //Get the CatOS Information
-		else { //Normal IF-MIB oids
+		if (is_catos($ip, $rocommunity)) 	// Check if its CatOS
+		    list ($ifDescr_oid, $ifAlias) = catos_info($ip, $rocommunity, $ifIndex); //Get the CatOS Information
+
+		elseif (is_webos($ip, $rocommunity)) 	// Check if its WebOS
+		    list($ifDescr,$ifAlias) = webos_info($ip, $rocommunity, $ifIndex);
+
+		else { 					//Normal IF-MIB oids
 		    $ifDescr_oid = ".1.3.6.1.2.1.2.2.1.2";
 		    $ifAlias_oid = ".1.3.6.1.2.1.31.1.1.1.18";
 		}
@@ -31,7 +43,7 @@
 		$ipAddEntIP 	= snmp_walk($ip,$rocommunity,".1.3.6.1.2.1.4.20.1.1");
 		$ipAddifIndex	= snmp_walk($ip,$rocommunity,".1.3.6.1.2.1.4.20.1.2");
 		$ipAddMask 	= snmp_walk($ip,$rocommunity,".1.3.6.1.2.1.4.20.1.3");
-
+		
 	        if (!is_array($ipAddifIndex)) $ipAddifIndex = array();
 
 		for ($i=0; $i < count($ifIndex) ; $i++) if ($ifIndex[$i]) {
@@ -40,11 +52,9 @@
 
 		    if ($ipPos !== false) {		//we Found some IPs for this interface index
 
-			list(, $ifAddr[$i])  = explode(":",$ipAddEntIP[$ipPos]); //Get the IP from that Pos
-		        $ifAddr[$i] = trim($ifAddr[$i]);
+		        $ifAddr[$i] = $ipAddEntIP[$ipPos]; //Get the IP from that Pos
 
-			list(, $ifAddrMask[$i])  = explode(":",$ipAddMask[$ipPos]); //Get the Mask from that Pos
-		        $ifAddrMask[$i] = trim($ifAddrMask[$i]);
+		        $ifAddrMask[$i] = $ipAddMask[$ipPos]; //Get the Mask from that Pos
 	
 			if (strpos($ifAddr[$i],".") > 0) { //IP Address for peer
 			    $aux = explode(".",$ifAddr[$i]);
@@ -58,8 +68,6 @@
 			    $peerAddr[$i] = implode(".",$aux);
 			}
 		    }
-		    
-		    list(, $ifSpeed[$i]) = explode(":",$ifSpeed[$i]);
 		    $ifSpeed[$i] = round($ifSpeed[$i]/1000);
 
 		    //Process MIB Status Values    
@@ -147,7 +155,7 @@
 	    }
 	    unset ($interface_names);
 	    unset ($aux1);
-	    
+
 	    return $snmp_interfaces;
     }
 ?>
