@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     //Linux TC Rate
 
 function graph_tc_rate ($data) { 
@@ -7,7 +11,7 @@ function graph_tc_rate ($data) {
 
     $opts_DEF["bits"]="CDEF:bits=bytes,UN,bytes,bytes,IF,8,*";
     
-    $opts_GRAPH = array_merge($opts_GRAPH,array(
+    $opts_GRAPH = array(
 	"HRULE:".$data["rate"]."#FF0000:'Configured Rate \: ".($data["rate"]/1000)." kbps\\n'",
 	"HRULE:".$data["ceil"]."#AAAAAA:'Configured Ceil \: ".($data["ceil"]/1000)." kbps\\n'",
 
@@ -20,7 +24,7 @@ function graph_tc_rate ($data) {
     	"GPRINT:packets:MAX:'Max\:%8.0lf %spps'",
     	"GPRINT:packets:AVERAGE:'Average\:%8.0lf %spps'",
     	"GPRINT:packets:LAST:'Last\:%8.0lf %spps'",
-	));
+	);
 
     $opts_header[] = "--vertical-label='Bits per Second'";
 
