@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     //Linux TC Rate Aggregation
 
 function graph_tc_rate_aggregation ($data) { 
@@ -15,6 +19,9 @@ function graph_tc_rate_aggregation ($data) {
     foreach ($color_array as $e) 
     	$colors[] = $a.$a.$c.$c.$e.$e;
     
+    $defs = array();
+    $graph = array();
+    
     foreach ($data[id] as $id) {
 	$interface=$data[$id];
 	$used_color = $colors[++$i*4];
@@ -26,11 +33,11 @@ function graph_tc_rate_aggregation ($data) {
 	    str_pad(($interface["rate"]/1000),4," ",STR_PAD_LEFT)." kbps"
 	    ,0,35);
 	
-	$defs = array_merge ($defs,
+	$defs = @array_merge ($defs,
 	    rrdtool_get_def($interface,array("bytes$id"=>"bytes")),
 	    array("CDEF:bits$id=bytes$id,UN,bytes$id,bytes$id,IF,8,*"));
 
-	$graph = array_merge ($graph, array(  
+	$graph = @array_merge ($graph, array(  
 		"LINE2:bits$id#$used_color:'$name'",
     		"GPRINT:bits$id:MAX:'Max\:%8.2lf %sbps'",
     		"GPRINT:bits$id:AVERAGE:'Average\:%8.2lf %sbps'",
