@@ -1,187 +1,180 @@
 <? 
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     $clean_url_del_vars=Array("bulk_add_ids","bulk_add");
     include ("../../auth.php");
     
-    if (!profile("ADMIN_HOSTS")) die ("<H1> You dont have Permission to access this page.</H1></HTML>");
+    if (!profile("ADMIN_HOSTS")) die (html("H1","You dont have Permission to access this page."));
 
     adm_header("Interfaces");
-?>
-<SCRIPT>
-function check(field_aux) {
-    field=document.forms[0].elements[field_aux];
-    for (i = 0; i < field.length; i++) { 
-	if (field[i].checked==true) field[i].checked = false; 
-	else	field[i].checked = true; 
-    }
-    return true;
-}
-</SCRIPT>
-<?
-    unset($old_action);
 
+    echo script ("
+    function check(field_aux) {
+	field=document.forms[0].elements[field_aux];
+	for (i = 0; i < field.length; i++) { 
+	    if (field[i].checked==true) 
+		field[i].checked = false; 
+	    else	
+		field[i].checked = true; 
+	}
+	return true;
+    }
+    ");
+
+    unset($old_action);
 
     function show_header($fields,$sample_data = array(),$number_of_showable_fields = 0) {
     
-	std_table_row();
+	echo tr_open("","header");
 
 	if (is_array($fields))
 	foreach ($fields as $field_name=>$data) 
 	    if ($data["showable"] > 0)
 		switch ($field_name) {
 		    case "action" :
-			if (is_numeric($GLOBALS["type_id"]))
-			    adm_table_header_cell("<font size=-2>".linktext("View all Types",$GLOBALS["REQUEST_URI"]."&type_id=&action=")."</font>","center",2);
-			else
-			    adm_table_header_cell("<font size=-2>".linktext($sample_data["type_description"],$GLOBALS["REQUEST_URI"]."&action=&type_id=".$sample_data["type"])."</font>","center",2);
+			echo td ( (is_numeric($GLOBALS["type_id"])
+			    ?linktext("View all Types",$GLOBALS["REQUEST_URI"]."&type_id=&action=")
+			    :linktext($sample_data["type_description"],$GLOBALS["REQUEST_URI"]."&action=&type_id=".$sample_data["type"]))
+			    ,"type_filter");
 		        break;
     		    case "row_filler":
 			$rows = $data["max"]-$number_of_showable_fields;
 			if ($rows > 0)
-			    adm_table_header_cell("&nbsp;","center",$rows);
+			    echo td("&nbsp;","row_filler","",$rows);
 			break;
 		    default: 
-			adm_table_header_cell($data["description"],"center");
+			echo td($data["description"],"field","field_".$field_name);
 		}
 
-	adm_table_row_close();
+	echo tag_close("tr");
     }
 
     function show_values ($fields,$values,$edit = 0, $ids = array(),$cant = 1, $number_of_showable_fields = 0) {
     
 	if (is_array($fields))
 	foreach ($fields as $field_name=>$data) if ($data["showable"] > 0) {
+	
 	    if (isset($values[$field_name]))
 		$value = $values[$field_name];
 	    else
 		$value = $data["default_value"];
 
+	    unset ($content);
+
 	    switch ($field_name) {
 		case "action" :
 		    if ($cant != 0) {
 		        if ($edit) 
-		    	    adm_table_cell(adm_form_submit(),"center",2);
+			    echo td (adm_standard_submit_cancel("Save","Discard"), "action");
 			else
-			    adm_standard_edit_delete(1,$values["id"]);
+			    echo adm_standard_edit_delete($values["id"],false);
 		    } else
-		    	    adm_table_cell(
-				adm_form_submit()."<br>".
-				radiobutton("action",$GLOBALS["action_select"]["update"],"update")."Update",
-		    		"center",2);
+		    	    $content = adm_form_submit().br().
+				radiobutton("action",$GLOBALS["action_select"]["update"],"update")."Update";
 		    break;
     		
 		case "id" :
 		    if ($cant != 0) { 
 			if ($edit)
-			    adm_table_cell(checkbox_value("actionid[]",$value,1)." ".$value,"center");
+			    $content = checkbox_value("actionid[]",$value,1)." ".$value;
 			else {
-			    if (in_array($value,$ids) or ($cant==1)) $check = 1; else $check=0;
-			    adm_table_cell(checkbox_value("actionid[]",$value,$check). html_indenter()." ".$value);
+			    $check = ((in_array($value,$ids) or ($cant==1))?1:0);
+			    $content = checkbox_value("actionid[]", $value, $check)." ".$value;
 		        }
 		    } else
-		    	adm_table_cell("<input type=checkbox onClick=\"this.value=check('actionid[]');\"> All<br>","center",1);
+		    	$content = checkbox_value("","",false,true, "this.value=check('actionid[]');")." All".br();
 
 		    break;
 
 		case "host":
-		    if ($edit)
-			adm_table_cell(select_hosts("host",$value));
-		    else
-			adm_table_cell($values["host_name"]." ".$values["zone_shortname"]);
+		    $content = ($edit)
+			?select_hosts("host",$value)
+			:$values["host_name"]." ".$values["zone_shortname"];
 		    break;
 
 		case "type": 
-		    if ($edit)
-			adm_table_cell(select_interface_types($field_name,$value));
-		    else
-			adm_table_cell($values["type_description"]);
+		    $content = ($edit)
+			?select_interface_types($field_name,$value)
+			:$values["type_description"];
 		    break;
 
 		case "poll": 
-		    if ($edit)
-			adm_table_cell(select_pollers_groups($field_name,$value,$values["type"]),"center");
-		    else
-			adm_table_cell($values["poller_group_description"],"center");
+		    $content = ($edit)
+			?select_pollers_groups($field_name,$value,$values["type"])
+			:$values["poller_group_description"];
 		    break;
 
 		case "interface": 
-		    if ($edit)
-			adm_table_cell(textbox($field_name,$value,20));
-		    else
-			adm_table_cell($values["interface"]);
+		    $content = ($edit)
+			?textbox($field_name,$value,20)
+			:$values["interface"];
 		    break;
 
 		case "client": 
-		    if ($edit)
-			adm_table_cell(select_clients($field_name,$value));
-		    else
-			adm_table_cell($values["client_name"]);
+		    $content = ($edit)
+			?select_clients($field_name,$value)
+	    		:$values["client_name"];
 		    break;
 		
 		case "sla": 
-		    if ($edit)
-			adm_table_cell(select_slas($field_name,$value,$values["type"]),"center");
-		    else
-			adm_table_cell($values["sla_description"],"center");
+		    $content = ($edit)
+			?select_slas($field_name,$value,$values["type"])
+			:$values["sla_description"];
 		    break;
 		
 		case "check_status": 
 		case "make_sound": 
-		    if ($edit)
-			adm_table_cell(checkbox($field_name,$value),"center");
-		    else
-			adm_table_cell(checkbox($field_name,$value,0),"center");
+		    $content = ($edit)
+			?checkbox($field_name,$value)
+			:checkbox($field_name,$value,0);
 		    break;
 
-		case "show_rootmap": 
-		    adm_table_cell(select_show_rootmap($field_name,$value,!$edit),"center");
+		case "show_rootmap":
+		    $content = select_show_rootmap($field_name,$value,!$edit);
 		    break;
 
     		case "row_filler":
 		    $rows = $data["max"]-$number_of_showable_fields;
 		    
 		    if ($rows > 0)
-		        adm_table_header_cell("&nbsp;","center",$rows);
+		        echo td("&nbsp;","row_filler","",$rows);
 		    break;
 		
 		case "poll_interval": 
-		    if ($edit)
-			adm_table_cell(select_poll_interval($field_name,$value),"center");
-		    else
-			adm_table_cell(select_poll_interval($field_name,$value,1),"center");
+		    $content = select_poll_interval($field_name,$value,!$edit);
 		    break;
 
 		case "creation_date" :
 		case "modification_date" :
 		case "last_poll_date" :
 
-		    if ($cant!=0)
-			adm_table_cell(show_unix_date($values[$field_name]),"center");
-		    else
-		        adm_table_cell("&nbsp;");
-			
+		    $content = ($cant!=0)
+			?show_unix_date($values[$field_name])
+			:"&nbsp;";
 		    break;
 		    		
 		default: 
 		    switch ($data["type_handler"]) {
 
 			case "bool" : //check box
-			    if ($edit)
-				adm_table_cell(checkbox($field_name,$value),"center");
-			    else
-				adm_table_cell(checkbox($field_name,$value,0),"center");
-			    
+			    $content = checkbox($field_name,$value,$edit);
 			    break;
 			    
 			case "text" : //text is the pseudo-default
 			default  :
-			    if ($edit && ($data["overwritable"]==1))
-				adm_table_cell(textbox($field_name,$value,20));
-			    else 
-				adm_table_cell($value,(is_numeric($value)?"right":""));
+			    $content = ($edit && ($data["overwritable"]==1))
+				?textbox($field_name,$value,20)
+				:$value;
 			    break;
 		    }
+	    	
 	    }
 
+	    if (isset($content))
+	        echo td($content, "field", "field_".$field_name);
+	    
 	    if (($edit==1) && ($cant!=0) && ($data["overwritable"]==1)) //normal one interface edit
 		echo hidden("update_fields[]",$field_name);
 
@@ -191,34 +184,38 @@ function check(field_aux) {
 
     function show_multiple_edit_boxes ($fields, $number_of_showable_fields) {
     	if (is_array($fields)) {
-	    foreach ($fields as $field_name=>$data) if ($data["showable"] > 0)
+	    foreach ($fields as $field_name=>$data) if ($data["showable"] > 0) {
+		unset ($content);
+		$rows = 1;
+		
 		switch ($field_name) {
 		    case "action" :
-			adm_table_cell(radiobutton("action",$GLOBALS["action_select"]["delete"],"delete")."Delete","center",2);
+			$content = radiobutton("action",$GLOBALS["action_select"]["delete"],"delete")."Delete";
 			break;
 			
 		    case "id": 
-		        adm_table_cell("Multiple<br>Edit","center",1);
+		        $content = "Multiple".br()."Edit";
 			break;
 
 		    case "row_filler":
 			$rows = $data["max"]-$number_of_showable_fields;
-		        if ($rows > 0)
-			    adm_table_header_cell("&nbsp;","center",$rows);
-			break;
 		
 		    case "creation_date" :
 		    case "modification_date" :
 		    case "last_poll_date" :
-		        adm_table_cell("&nbsp;");
+		        if ($rows > 0)
+			    $content = "&nbsp;"; 
 			break;
 			
 		    default:
-			if ($data["overwritable"]==1)
-			    adm_table_cell(checkbox_value("update_fields[]",$field_name,0),"center");
-			else
-		    	    adm_table_cell("&nbsp;");
+			$content = ($data["overwritable"]==1)
+			    ?checkbox_value("update_fields[]",$field_name,0)
+			    :"&nbsp;";
 		}
+	    
+		if (!empty($content))
+		    echo td ($content, "field", "field_".$field_name, $rows);
+	    }
 	}
     }
     
@@ -237,7 +234,7 @@ function check(field_aux) {
 	"check_status"	=>array("description"=>"Check Status", 	"default_value"=>1, 	"showable"=>1,	"overwritable"=>1),
 	"sla"		=>array("description"=>"SLA", 		"default_value"=>1, 	"showable"=>1,	"overwritable"=>1),
 	"make_sound"	=>array("description"=>"Enable Sound?", "default_value"=>0, 	"showable"=>1,	"overwritable"=>1),
-	"show_rootmap"	=>array("description"=>"Show in Maps?", "default_value"=>0, 	"showable"=>1,	"overwritable"=>1),
+	"show_rootmap"	=>array("description"=>"Show", 		"default_value"=>0, 	"showable"=>1,	"overwritable"=>1),
 	"poll_interval" =>array("description"=>"Polling Interval", "default_value"=>0, 	"showable"=>1,	"overwritable"=>1),
 	"creation_date"	=>array("description"=>"Creation Date", 			"showable"=>1,	"overwritable"=>0),
 	"modification_date"=>array("description"=>"Modification Date", 			"showable"=>1,	"overwritable"=>0),
@@ -338,7 +335,7 @@ function check(field_aux) {
     if (isset($filter)) $filters["host"] = $filter;
     $cant = $api->get($use_interfaces, $filters);
 
-    adm_table_header("Interfaces",$init,&$span,$max_fields,$cant);
+    echo adm_table_header("Interfaces", $init, &$span, $max_fields, $cant, "admin_interfaces", false);
 
     if ($cant > 0) {
 	$types_fields = $api->fetch();
@@ -358,19 +355,22 @@ function check(field_aux) {
 	$old_interface_type = 0;
 	$number_of_types = 0;
 	
-        adm_form("update");
-
-        reports_pass_options();
+	echo 
+    	    adm_form("update", "POST", "_self", false).
+	    reports_pass_options();
 
 	while ($register = $api->fetch()) {
-	    table_shift_color($color);
 
 	    if ($register["type"]!=$old_interface_type) {
-
-		$type_fields = array_merge($fields_init,$types_fields[$register["type"]],$fields_end);
+		echo tag ("tbody","itype_".$register["type"]);	
+	    
+		$type_fields = array_merge($fields_init,
+		    (is_array($types_fields[$register["type"]])?$types_fields[$register["type"]]:array()),    
+		    $fields_end);
 	
 		show_header ($type_fields, $register,$num_fields[$register["type"]]);
-	
+		$row = 0;
+		
 		$old_interface_type = $register["type"];
 		$number_of_types++;
 	    }
@@ -380,16 +380,16 @@ function check(field_aux) {
 	    else 
 		$edit = 0;
 
-	    adm_table_row($color);
+	    echo tr_open("row_".$register["id"],($edit)?"editing":((($row++%2)!=0)?"odd":""));
 
 	    show_values ($type_fields,$register,$edit,$actionid,$cant,$num_fields[$register["type"]]);
 
-	    adm_table_row_close();
+	    echo tag_close("tr");
 	}
+	echo tag_close("tbody");
+	
 	
 	if (($action!="edit") && ($cant > 1)) { //multiple editor
-	    table_row("&nbsp;","center",$max_fields);
-	    std_table_row($color);
 
 	    if ($number_of_types > 1) {
 		$multiple_edit_fields = array_merge($fields_init, $fields_end);
@@ -397,46 +397,57 @@ function check(field_aux) {
 	    } else 
 		$multiple_edit_fields = $type_fields;
 
+
+	    table_row("&nbsp;","",$max_fields);
+	    
+	    echo tr_open("multi_editor");
+
 	    show_values ($multiple_edit_fields,array("type"=>$old_interface_type),1,0,0,$num_fields[$old_interface_type]);
 
-	    adm_table_row_close();
-		    
-	    std_table_row($color);
+	    echo 
+		tag_close("tr").
+		tr_open("multi_editor_checkboxes");
+	
 	    show_multiple_edit_boxes($multiple_edit_fields,$num_fields[$old_interface_type]);
-	    adm_table_row_close();
+	    
+	    echo tag_close("tr");
 	}
 	
 	if ($cant > 0) { //if theres an interface listed
 
-	    if ($action!="edit") { //if we are in edit mode
-	    
-		std_table_row($color);
-		if ($cant == 1) { //if the other option arent showing, show a Submit button
-		    adm_table_cell(
-			adm_form_submit("Add To Map")."<br>".
-		        hidden("action","map"),
-			"center",2);
-		} else 
-		    adm_table_cell(radiobutton("action",$action_select["map"],"map")."Add to Map:<br>","center",2);
-
-		adm_table_cell(select_maps("add_to_map_id",$add_to_map_id),"center",2);
-	        adm_table_cell(linktext("<small>View Map</small>","$jffnms_rel_path/admin/adm/adm_standard.php?admin_structure=maps_interfaces&filter=$add_to_map_id"),"",1);
-		adm_table_cell("&nbsp;","",$max_fields-5);
-		adm_table_row_close();
-	    }
+	    if ($action!="edit") //if we are in edit mode
+		echo 
+		    tr_open ("options").
+		    td ((($cant == 1) //if the other option arent showing, show a Submit button
+			    ?adm_form_submit("Add To Map").br().hidden("action","map")
+			    :radiobutton("action",$action_select["map"],"map")."Add to Map:".br())
+			,"field","add_to_map").
+		
+		    td(select_maps("add_to_map_id",$add_to_map_id),"field","add_to_map_select",2).
+		    td(linktext("View Map", $jffnms_rel_path."/admin/adm/adm_standard.php?admin_structure=maps_interfaces&filter=".$add_to_map_id),
+			"field","view_map");
+		    td("&nbsp;","row_filler","",$max_fields-5).
+		    tag_close("tr");
 	
 	    //Shortcuts
-	    std_table_row($color);
-	    adm_table_cell(linktext(adm_image("$jffnms_rel_path/images/graph.png","","",0,0,"Performance")." Performance","$jffnms_rel_path/view_performance.php?".$_SERVER["QUERY_STRING"].$interfaces_url),"center",2);
-	    adm_table_cell(linktext(adm_image("$jffnms_rel_path/images/text.png","","",0,0,"Report")." Report","$jffnms_rel_path/admin/reports/state_report.php?".$_SERVER["QUERY_STRING"].$interfaces_url),"center",1);
-	    adm_table_cell(linktext(adm_image("$jffnms_rel_path/images/text.png","","",0,0,"Alarms")." Alarms","$jffnms_rel_path/admin/adm/adm_alarms.php?".$_SERVER["QUERY_STRING"].$interfaces_url),"center",1);
-
-	    adm_table_cell("&nbsp;","",$max_fields-4);
-	    adm_table_row_close();
+	    echo 
+		tr_open("shortcuts").
+		td(linktext(image("graph.png","","","Performance").
+		    " Performance",$jffnms_rel_path."/view_performance.php?".$_SERVER["QUERY_STRING"].$interfaces_url),
+		    "","",2).
+		td(linktext(image("text.png","","","Report").
+		    " Report",$jffnms_rel_path."/admin/reports/state_report.php?".$_SERVER["QUERY_STRING"].$interfaces_url)).
+		td(linktext(image("text.png","","","Alarms").
+		    " Alarms",$jffnms_rel_path."/admin/adm/adm_alarms.php?".$_SERVER["QUERY_STRING"].$interfaces_url)).
+		td("&nbsp;","row_filler","",$max_fields-4).
+		tag_close("tr");
 	}
     } else 
-	table_row("<br><b>No Records Found.</b>","center",$max_fields);
+	table_row("No Interfaces Found","no_records_found",$max_fields);
     
-    adm_form_close();
+    echo 
+	table_close().
+	form_close();
+
     adm_footer();
 ?>
