@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     class internal_base_custom extends basic {
         function get_all()	{ $params = func_get_args(); return call_user_func_array($this->jffnms_class."_list",$params); }
         function add() 		{ $params = func_get_args(); return call_user_func_array("adm_".$this->jffnms_class."_add",$params); }
@@ -12,7 +16,7 @@
 	var $jffnms_order_field = "id";
 	var $jffnms_order_type = "desc";
 
-        function get_all($ids = NULL)	{ 
+        function get_all($ids = NULL, $fields = array()) { 
 	    return get_db_list(	$this->jffnms_class,	$ids, 	array($this->jffnms_class.".*"), //table,ids,fields	
 		array(array($this->jffnms_class.".id",">",$this->jffnms_filter_record)), //where
 		array(array($this->jffnms_class.".".$this->jffnms_order_field,$this->jffnms_order_type)) ); //order 
@@ -39,6 +43,7 @@
 
     class jffnms_hosts 		extends internal_base_custom 	{ 
 	var $jffnms_class = "hosts"; 
+	var $jffnms_insert = array("name"=>"New Host"); 
 
 	function count()		{ $params = func_get_args(); return call_user_func_array("hosts_count",$params); }
 	function poller_plan()		{ $params = func_get_args(); return call_user_func_array("poller_plan",$params); }
@@ -369,6 +374,7 @@
 
 
     class jffnms_users extends basic {
+	var $jffnms_class = "auth";  
 
         function get_all()	{ $params = func_get_args(); return call_user_func_array("users_list",$params); }
         function add() 		{ $params = func_get_args(); return call_user_func_array("user_add",$params); }
@@ -489,6 +495,42 @@
 	    return $this->_count();
 	}
     
+	function get_empty_record () {
+	    //Get the 'Unknown' Record 1
+	    $aux = current(get_db_list(	$this->jffnms_class,	1, 	array($this->jffnms_class.".*"))); //table,ids,fields	
+
+	    foreach ($aux as $key=>$value) 	//fill the values with the default data
+		$aux[$key] = (isset($this->jffnms_insert[$key])?$this->jffnms_insert[$key]:$value);
+	    
+	    return $aux;
+	}
+    
+	function field_values ($fields = NULL) {
+	    $values = array();
+
+	    $all_records = $this->get_all();
+	    
+	    while (list(,$row) = each ($all_records)) 
+		while (list($field, $value) = each ($row))
+		    if ($fields===NULL)
+			$values[$field][]=$value;
+	            else 
+			if (isset($fields[$field]))
+			    $values[$field][$value]=$row[$fields[$field]];
+		
+	    unset ($values["id"]);
+	    
+	    while (list ($field, $value) = each ($values)) {
+		$values[$field] = array_unique($value);
+		asort ($values[$field]);
+		$values[$field] = array(""=>"") + $values[$field];
+	    }
+	    
+	    reset ($values);
+	    
+	    return $values;
+	}
+    
 	function verify_operations() {
 	    $add = $this->add();
 	    $upd = $this->update($add,array("id"=>$add));
