@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
 //ALARMS
 //---------------------------------------------
 
@@ -147,8 +151,11 @@
     }
     
     function events_ack($id,$ack = 1) {
-	if ($ack == 1) $result = db_query ("update events set ack='$ack' where ack = 0 and id = '$id'"); //dont overwrite the journal
-	else $result = db_update("events",$id,array(ack=>$ack)); //if it's journal, overerite
+	if ($ack == 1) 
+	    $result = db_query ("update events set ack='$ack' where ack = 0 and id = '$id'"); //dont overwrite the journal
+	else 
+	    $result = db_update("events",$id,array("ack"=>$ack)); //if it's journal, overerite
+
 	return $result;
     }
     
@@ -174,7 +181,7 @@
 	    "<events_table>.type as type_id, severity.severity, zones.id as zone_id, zones.zone as zone_name, ".
 	    "severity.level as severity_level, severity.fgcolor, severity.bgcolor, <events_table>.interface, ".
 	    "<events_table>.username as user, <events_table>.state, <events_table>.info, types.text, types.show_host, ".
-	    "<events_table>.ack, clients.name as interface_customer, interfaces.id as interface_id, interfaces.client ";
+	    "<events_table>.ack, clients.name as interface_customer, interfaces.id as interface_id, interfaces.client as interface_client_id ";
 	
 	$query_from  = "hosts, types, severity, zones, <events_table> ";
 
