@@ -1,14 +1,21 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     function hosts_status ($host_id = NULL, $map_id = NULL, $only_in_rootmap = 0, $client_id = NULL) {
 	return interfaces_status(NULL,array("host"=>$host_id,"map"=>$map_id,"in_maps"=>$only_in_rootmap, "show_disabled"=>0, "client"=>$client_id));
     }
 
     function hosts_list($ids = NULL, $zone_id = NULL, $where_special = NULL, $count = 0) {
 
+	if (is_array($zone_id))
+	    return hosts_list_filtered($zone_id);
+
 	$index = "hosts.id";
     
     	if (!is_array($where_special)) $where_special = array();
-	if ($zone_id) $where_special[]=array("hosts.zone","=",$zone_id);
+	if (is_numeric($zone_id)) $where_special[]=array("hosts.zone","=",$zone_id);
 
 	$order = array (
 	    array("hosts.name","asc"),
@@ -47,15 +54,37 @@
 	    $index);
     }
 
+    function hosts_list_filtered ($filters = array()) {
+	$interfaces = interfaces_list(NULL,$filters);
+	
+	while (list(,$int) = each ($interfaces)) 
+	    $hosts[]=$int["host"];
+	
+	$hosts = array_unique($hosts);
+	return hosts_list($hosts);
+    }
+
     function hosts_count($ids = NULL, $zone_id = NULL, $where_special = NULL) {
 	return current(current(hosts_list($ids, $zone_id, $where_special, 1)))-1;
     }
     
     function adm_hosts_add($zone_id = 1) {
-	return db_insert("hosts",array("name"=>"New Host","zone"=>$zone_id));
+	if (!is_numeric($zone_id)) $zone_id = 1;
+	
+	return db_insert("hosts", array("name"=>"New Host", "zone"=>$zone_id, "creation_date"=>time()));
     }
 
     function adm_hosts_update($host_id,$host_data) {
+	
+	// if the only fields to update are the last_poll_* ones don't update the modification_date
+    	if ((count($host_data)==2) && isset($host_data["last_poll_date"]) && isset($host_data["last_poll_time"])) 
+	    ;
+	else
+	    $host_data["modification_date"]=time(); //update the modification date
+
+	if (isset($host_data["dmii"]) && (substr($host_data["dmii"],0,1)!="M") && (substr($host_data["dmii"],0,1)!="I")) 
+	    $host_data["dmii"] = 1;
+	
 	$result = db_update("hosts",$host_id,$host_data);
 	return $result;
     }
@@ -148,17 +177,18 @@
             );
     }
 
-    function hosts_config_diff($id1,$id2) {
-	global $images_real_path,$diff_executable;
+    function hosts_config_diff ($id1, $id2) {
 
 	if ($id1 != $id2) {
+
 	    $aux = hosts_config_list(array($id1,$id2));
-	    //debug ($aux);
-	    $str1 = $aux[0][config];
-	    $str2 = $aux[1][config];
+	    $str1 = $aux[0]["config"];
+	    $str2 = $aux[1]["config"];
 	
-	    $name1 = "$images_real_path/diff-config-1-".rand().".log";
-	    $name2 = "$images_real_path/diff-config-2-".rand().".log";
+	    $engine_temp = get_config_option("engine_temp_path");
+	
+	    $name1 = $engine_temp."/".uniqid("").".dat";
+	    $name2 = $engine_temp."/".uniqid("").".dat";
 
 	    $pf = fopen($name1,"w");
 	    fputs($pf,$str1);
@@ -168,12 +198,21 @@
 	    fputs($pf,$str2);
 	    fclose($pf);
 
-	    $c = exec("$diff_executable -Nru $name1 $name2",$a,$b);
+	    $diff_executable = get_config_option("diff_executable");
 
-	    unlink($name1);
-	    unlink($name2);
-	    return $a;
-	} return FALSE;
+	    if (file_exists($diff_executable)) {
+		$c = exec($diff_executable." -Nru ".$name1." ".$name2, $diff);
+
+		unlink($name1);
+	        unlink($name2);
+	    
+	        $diff = join("\n",array_slice($diff, 3));
+	    
+		return $diff;
+	    }
+	}
+	
+	return false;
     }
 
     function hosts_config_put($host_id,$filename) {
@@ -182,20 +221,20 @@
 
 	if ($host[tftp_mode]==1) { //OLD-CISCO-SYS-MIB
 	    $oid = ".1.3.6.1.4.1.9.2.1.53.$host[tftp]";
-	    $aux = snmpset($host[ip],$host[rwcommunity],$oid,"s",$filename,60,0);
+	    $aux = snmp_set($host[ip],$host[rwcommunity],$oid,"s",$filename,60,0);
 	    if ($aux==TRUE) $result = 2;
 	}
 	    
 	if ($host[tftp_mode]==0) { //CISCO-CONFIG-COPY-MIB
 	    $oid = ".1.3.6.1.4.1.9.9.96.1.1.1.1";
-	    snmpset($host[ip],$host[rwcommunity],"$oid.14.999","i",6); //destroy
-	    snmpset($host[ip],$host[rwcommunity],"$oid.14.999","i",5); //create and wait
-	    snmpset($host[ip],$host[rwcommunity],"$oid.2.999","i","1"); //tftp
-	    snmpset($host[ip],$host[rwcommunity],"$oid.3.999","i","1"); //running
-	    snmpset($host[ip],$host[rwcommunity],"$oid.4.999","i","4"); //network
-	    snmpset($host[ip],$host[rwcommunity],"$oid.5.999","a",$host[tftp]); //server
-	    snmpset($host[ip],$host[rwcommunity],"$oid.6.999","s",$filename); //filename
-	    snmpset($host[ip],$host[rwcommunity],"$oid.14.999","i",1); //activate
+	    snmp_set($host[ip],$host[rwcommunity],"$oid.14.999","i",6); //destroy
+	    snmp_set($host[ip],$host[rwcommunity],"$oid.14.999","i",5); //create and wait
+	    snmp_set($host[ip],$host[rwcommunity],"$oid.2.999","i","1"); //tftp
+	    snmp_set($host[ip],$host[rwcommunity],"$oid.3.999","i","1"); //running
+	    snmp_set($host[ip],$host[rwcommunity],"$oid.4.999","i","4"); //network
+	    snmp_set($host[ip],$host[rwcommunity],"$oid.5.999","a",$host[tftp]); //server
+	    snmp_set($host[ip],$host[rwcommunity],"$oid.6.999","s",$filename); //filename
+	    snmp_set($host[ip],$host[rwcommunity],"$oid.14.999","i",1); //activate
 	    $result = snmp_get($host[ip],$host[rwcommunity],"$oid.10.999");
 	}
 
@@ -216,7 +255,11 @@
 					  $filter.=" and ( interfaces.id = ".join(" or interfaces.id = ",$data)." )"; 
 					  break;
 	
-		case "host"		: if ($data>1) $filter.=" and hosts.id = $data"; break;
+		case "host"		: 
+		case "hosts"		: if (!is_array($data) && (strpos($data,",")!==false)) $data = explode(",",$data);
+					  if (!is_array($data)) $data = array($data);
+					  $filter.=" and ( hosts.id = ".join(" or hosts.id = ",$data)." )"; 
+					  break;
 		case "type"		: if ($data>1) $filter.=" and interfaces.type = $data"; break;
 		case "pos" 		: if ($data>0) $filter.=" and pollers_poller_groups.pos = $data"; break;
 	    }
@@ -247,7 +290,7 @@
 		    pollers_poller_groups.pos, interfaces.id";
 
 	$result = db_query ($query_poller) or die ("Query failed - poller_plan - ".db_error());	
-	//debug ($query_poller);	
+	//debug ($query_poller);
 	
 	$random = rand(10,99);
 	$time_start = time_usec();
@@ -255,6 +298,7 @@
 	
 	while ($data = db_fetch_array($result)) {
 	    $id = $data["interface_id"];
+	    $interface_ids[$id] = true; //to count the number of interfaces
 
 	    $fields = array("interface","show_rootmap","rw_community","ro_community","host_id",
 	        "host_ip","autodiscovery_parameters");
@@ -293,7 +337,9 @@
 
 	reset ($poller_plan);
 	
-	return array("interface_data"=>$interfaces, "plan"=>$poller_plan, "items"=>count($poller_plan),"random"=>$random, "time_start"=>$time_start);
+	return array("interface_data"=>$interfaces, "plan"=>$poller_plan, 
+	    "items"=>count($poller_plan)+count($interface_ids), //number of items + 1 per 1 interface LPD
+	    "random"=>$random, "time_start"=>$time_start);
     }
     
     function poller_plan_next (&$result) {
