@@ -1,31 +1,25 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
 
 //DEBUG
 //-----------------------------------------
 
-    function logger($text,$show_date = 1) {
-	global $log_path,$argv,$jffnms_debug,$sat_id,$method;
+    function logger($text, $show_date = true) {
+	global $sat_id, $method;
+
+	$text = (($show_date==true)?date("H:i:s")." ":"").$text;
+
+	if (get_config_option("jffnms_debug")==1) {
+
+	    $file = str_replace(".php","",basename($GLOBALS["jffnms_logging_file"]));
+	    $filename = get_config_option("log_path")."/".$file."-".date("Y-m-d").".log";
 
-	if ($jffnms_debug==1) {
-	    unset($aux);
-	    $script = $GLOBALS["jffnms_logging_file"];
-	    $today = date("Y-m-d",time());
-    
-	    if (!$script) $aux = $_SERVER[argv][0];
-		else $aux = $script;
-    
-	    $file = str_replace(".php","",basename(strval($aux)));
-	    $filename = "$log_path/$file-$today.log";
-	    unset ($aux);
-	    unset ($file);
-	    unset ($today);
-	    
-	    if ($show_date==1) $hour = date("H:i:s",time());
-    
 	    $log = fopen($filename,"a+");
-	    fputs($log,"$hour $text");
+	    fputs($log, $text);
 	    fclose($log);
-	    unset ($log);
 	}
 	
 	//if (!isset($sat_id) && !isset($method)) //don't show anything if we're on a satellite //FIXME
@@ -39,6 +33,14 @@
 	flush();
     }
 
+    function d($text) {
+	echo "\n<PRE>";
+	var_dump($text);
+	echo "</PRE>\n";
+	flush();
+    }
+
+
     function vd_tab ($cant) {
 	return @str_repeat("\t",$cant);
     }
@@ -85,20 +87,21 @@
 	return $GLOBALS["jffnms_configuration"][$option]["value"]; 
     }
     
-    function save_ini ($config,$profile,$really) {
+    function save_configuration ($file, $config = array(), $really = false) {
+	global $jffnms_configuration;
+
+	$new_config_name = $file . "." . date("Y-m-d",time());
 	
-	$new_config="[$profile]\n";
+	foreach ($config as $key=>$value)
+	    if ($value!=$jffnms_configuration[$key]["default"])
+		$new_config .= $key." = ".$value."\n";
 
-	foreach ($GLOBALS["jffnms_configuration"] as $key=>$data)
-	    $new_config .="\t$key = ".$data["value"]." # ".$data["type"].",".$data["size"].",".$data["comment"]."\n";	
-
-	$date = date("Y-m-d",time());
-	$fp = fopen("$config-$date","w+");
-	fputs($fp,$new_config);
-	fclose($fp);
+	$fp = fopen($new_config_name,"w+");
+	@fputs($fp, $new_config);
+	@fclose($fp);
     
-        copy($config,"$config.old");
-	if ($really==1) copy("$config-$date",$config);
+	if (($really==true) && (file_exists($new_config_name))) 
+	    copy($new_config_name, $file);
     }
 
 
@@ -369,22 +372,27 @@
 	    $field_name = is_numeric($new_key)?end(explode(".",$key)):$new_key;
 	    $order = ($order=="desc")?SORT_DESC:SORT_ASC;
 	    
-	    if ($field_name=="interface") $order = 0;
+	    if ($field_name=="interface") $order = SORT_NUMERIC;
 
-	    //debug ($order);
 	    $result[$field_name]=$order;
     	}
+	
 	//debug ($result);
 	return $result;    
     }
 
-    function array_rekey($array, $key) {
+    function array_rekey($array, $key, $old_key_name = false) {
     
 	reset($array);
 	
-	while (list(,$data) = each ($array))
-	    $new[$data[$key]]=$data;
-				
+	while (list($old_key,$data) = each ($array)) {
+	    $new_key = $data[$key];
+	    $new[$new_key]=$data;
+
+	    if ($old_key_name!==false) 
+		$new[$new_key][$old_key_name]=$old_key;
+	}
+	
 	return $new;
     }
 
@@ -405,5 +413,54 @@
 	 
 	return false;
     }
+
+    function time_hms () {
+	//Find the first numeric parameter
+	$args = func_get_args();
+	while (($unixtime = current($args)) && !is_numeric($unixtime) && ($aux = next($args)));
+
+	return str_pad(floor($unixtime/(60*60)),2,"0",STR_PAD_LEFT).date(":i:s",$unixtime);
+    }
+
+    function array_record_search ($rows, $needle_field, $needle_value) {
+	$result = array();
+	
+	if (is_array($rows)) {
+	    reset($rows);
+
+	    while (list ($id, $row) = each ($rows))
+		if ($row[$needle_field] == $needle_value)
+		    $result[$id]=$row;
+	}
+	
+	return $result;
+    }    
     
+    function byte_format($input, $dec = 0) {
+	$prefix_arr = array("", "K", "M", "G", "T");
+        $value = round($input, $dec);
+
+	while ($value > 1024) {
+	    $value /= 1024;
+	    $i++;
+	}
+	
+	$return_str = round($value, $dec)." ".$prefix_arr[$i];
+	return $return_str;
+    }
+    
+    function detach() {
+	if (function_exists("pcntl_fork") && ($GLOBALS["start_debug"]!=1)) {
+	    if (($launcher_forkpid = pcntl_fork()) == -1) 
+    		die("could not fork\n");
+	    else 
+		if ($launcher_forkpid) // we are the parent
+		    exit();
+    
+	    return true;
+	}
+	
+	return false;
+    }
+
 ?>
