@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
 
     function interfaces_filter($filters = NULL) {
 	$from = array();
@@ -262,6 +266,7 @@
 		    "host_name"=>"hosts.name",
 		    "host_ip"=>"hosts.ip",
 		    "host_show"=>"hosts.show_host",
+		    "host_poll_interval"=>"hosts.poll_interval",
 		    "client_name"=>"clients.name",
 		    "client_shortname"=>"clients.shortname",
 		    "sla_description"=>"slas.description",
@@ -271,6 +276,7 @@
 		    "zone"=>"hosts.zone",
 		    "zone_name"=>"zones.zone",
 		    "zone_image"=>"zones.image",
+		    "zone_show"=>"zones.show_zone",
 		    "zone_shortname"=>"zones.shortname"
 		    ),
 		$aux_fields);
@@ -287,7 +293,9 @@
 	if ($count) $result = current(current($result));
 	else 
 	    if (count($result) > 0) {
+
 		array_key_sort(&$result,convert_sql_sort($fields, $order));
+
 		if ($index!=NULL) $result = array_rekey($result, "id");
 							    
 		//Get Interface Fields Values
