@@ -1,29 +1,21 @@
 <?
-    function snmp_netsnmp_fix ($value) {
-	//BUGFIXES FOR NET-SNMP 5
-	$value=preg_replace("/INTEGER: /","",$value);
-	
-	if (preg_match("/STRING: \"(\S.+)\"/",$value,$parts)) $value = $parts[1];
-	$value=preg_replace("/STRING: /","",$value);
-
-	//$value=preg_replace("/IpAddress: /","",$value); //Breaks discovery/snmp_interfaces
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
+    // Frontend SNMP Functions for Current code.
     
-	$value = trim ($value);
-	
-	return $value;    
-    }
+    function snmp_walk ($host, $comm, $oid, $include_oid = false, $retries = 2) {
 
-    function snmp_walk ($host,$comm,$oid,$include_oid = 0,$retries = 2) {
-
-	if ($include_oid==0)
-	    $result = @snmpwalk($host,$comm,$oid,(1000000*1),$retries);
-	else 
-	    $result = @snmpwalkoid($host,$comm,$oid,(1000000*1),$retries); //OPTION to get OIDs in the key
+	$result = snmp_wrapper("walk", $host, $comm, $oid, $include_oid, $retries);
 	
 	if (is_array($result)) 
 	    foreach ($result as $key=>$aux) {
 		$aux = snmp_netsnmp_fix($aux);
-		if (strpos($aux,"=")) $aux = substr($aux,strpos($aux,"=")+2,strlen($aux));
+
+		if (strpos($aux,"=")!==false) 
+		    $aux = substr($aux, strpos($aux,"=")+2, strlen($aux));
+
 		$result[$key]=$aux;
 	    }	
 
@@ -31,15 +23,9 @@
 	return $result;
     }
 
-    function get_snmp_counter ($ip,$community,$oid) {
-	$aux = explode(":",@snmp_get($ip,$community,$oid));
-	if (count($aux)==1) $result = $aux[0];
-	    else $result = $aux[1];
-	return $result;
-    }
+    function snmp_get ($host, $comm, $oid, $retries = 2) { 
 
-    function snmp_get($host,$comm,$oid, $retries = 2) { 
-	$aux = @snmpget($host,$comm,$oid,(1000000*1), $retries);
+	$aux = snmp_wrapper("get", $host, $comm, $oid, false, $retries);
 
 	if ($aux!==false) {
 	    $aux = snmp_netsnmp_fix($aux);
@@ -50,10 +36,135 @@
 	return $aux;
     }
     
-    
-//MISC
-//--------------------------------------------------------
+    function snmp_set ($host, $comm, $oid, $type, $value, $timeout = 2) { 
 
+	$result = snmp_wrapper("set", $host, $comm, $oid.":".$type.":".$value, false, 1, $timeout);
+
+	//logger ("\nsnmpset $host:$comm $oid $type $value = ".vd($result)."\n");
+	
+	return ($result)?true:false;
+    }
+
+    // SNMP Wrapper Function
+    function snmp_wrapper($action, $ip, $raw_community, $oid, $include_oid = false, $retries = 2, $timeout = 1) {
+
+	if ($raw_community[2]!==":")			// default
+	    $raw_community = "v1:".$raw_community;	// SNMPv1
+
+	$parsed_comm = explode(":", $raw_community);
+	list ($version, $community) = $parsed_comm;
+	
+	if (empty($community)) return false;
+
+	$snmp_func = "jffnms_".(($version=="v1")?"snmp1":(($version=="v2")?"snmp2":(($version=="v3")?"snmp3":"")));
+	
+	if ($action=="set")
+	    list ($oid, $set_type, $set_value) = explode (":", $oid);
+	    
+	$oid = parse_oid($oid, $version);
+
+	$params = compact("action", "ip", "community", "oid", "include_oid", "retries", "timeout", "set_type", "set_value");
+	
+	//logger ("\nCalling $snmp_func ".vd($params)."\n");
+	return call_user_func_array ($snmp_func, array($params));
+    }
+
+    // Real SNMP Functions
+
+    function jffnms_snmp1 ($p) {
+
+	$params = array_merge(
+	    array($p["ip"], $p["community"], $p["oid"]), 
+	    (($p["action"]=="set")
+		?array($p["set_type"], $p["set_value"])
+		:array()),
+	    array($p["timeout"]*1000000,$p["retries"])); 
+
+	return @call_user_func_array("snmp".$p["action"].((($p["action"]=="walk") && ($p["include_oid"]))?"oid":""), $params);
+    }
+
+    function jffnms_snmp2 ($p) {
+
+	$func = "snmp".$p["action"]." -v2c ".(!$p["include_oid"]?"-Oqv":"")." -c '".$p["community"]."' -t ".$p["timeout"]." -r ".$p["retries"]." ".
+		$p["ip"]." ".$p["oid"].
+		(($p["action"]=="set")?" ".$p["set_type"]." ".$p["set_value"]:"");
+
+	//logger ("Command ".$func."\n");
+	@exec($func, $result, $aux);
+	
+	if ((count($result)==1) && 
+	    (preg_match("/No Such (Object|Instance)/i", current($result)) ||
+	     preg_match("/No more variables left/i", current($result))))
+	    $new_result = false; 
+
+	else {
+	
+	    if ($p["action"]=="get") $result = current($result);
+
+	    if ($p["include_oid"])
+		foreach ($result as $key=>$aux) {
+		    if (strpos($aux,"=")!==false) 
+			$key = substr($aux, 0, strpos($aux,"=")-1);
+		    $new_result[$key]=$aux;
+		}
+	    else
+		$new_result = $result;
+	}
+
+	//d($new_result);
+	return $new_result;
+    }
+
+    function jffnms_snmp3 ($p) {
+	list ($user, $level, $auth_protocol, $auth_key, $priv_proto, $priv_key) = explode("|", $p["community"]);
+
+	if (empty($priv_key)) $priv_key = $auth_key;
+
+	$params = array_merge(
+	    array($p["ip"], $user, $level, $auth_protocol, $auth_key, $priv_proto, $priv_key, $p["oid"]), 
+	    (($p["action"]=="set")
+		?array($p["set_type"], $p["set_value"])
+		:array()),
+	    array($p["timeout"]*1000000,$p["retries"])); 
+
+	return @call_user_func_array(
+	    "snmp3_".
+	    ((($p["action"]=="walk") && ($p["include_oid"]))?"real_":"").
+	    $p["action"], 
+	    $params);
+    }
+
+    // Aux SNMP Functions
+    
+    function get_snmp_counter ($ip,$community,$oid) {
+	$aux = explode(":",@snmp_get($ip,$community,$oid));
+	if (count($aux)==1) $result = $aux[0];
+	    else $result = $aux[1];
+	return $result;
+    }
+    
+    function parse_oid ($oid, $version = "v1") {
+	list ($oid_32, $oid_64) = explode (",",$oid);
+	
+	return (($version=="v1") || empty($oid_64))?$oid_32:$oid_64;
+    }
+
+    function snmp_netsnmp_fix ($value) {
+	//BUGFIXES FOR NET-SNMP 5
+	$value=preg_replace("/INTEGER: /","",$value);
+	
+	if (preg_match("/STRING: \"(\S.+)\"/",$value,$parts)) $value = $parts[1];
+	$value=preg_replace("/STRING: /","",$value);
+
+	$value = preg_replace("/IpAddress: /","",$value);
+
+	$value = preg_replace("/Gauge32: /","",$value);
+    
+	$value = trim ($value);
+	
+	return $value;    
+    }
+    
     function snmp_hex_to_string ($hex) {
 	$value = trim($hex);
 	if (substr($value,0,3)=="Hex") { 
@@ -69,6 +180,10 @@
 	return $value;
     }
 
+
+//MISC
+//--------------------------------------------------------
+
     function http_post_message ($url,$vars,$raw_data = "", $debug = 0,$comment = NULL, $HTTP_MODE = "1.0") {
 
 	unset($comment);    
@@ -176,7 +291,6 @@
         return $data;
     }
 
-
     function soap_post_message ($url, $vars, $debug = 0,$comment = NULL) {
 	
 	require_once "SOAP/Client.php";
