@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
 //CLASS
 //------------------------------------------------------------
 
@@ -6,8 +10,11 @@
 	var $jffnms_class = "profiles_values";  
 	var $jffnms_insert = array("description"=>"New Value"); 
 
-        function get_all($ids = NULL,$filters = NULL)	{ 
-	
+        function get_all($filter = NULL, $filters=NULL)	{ 
+
+	    if (is_numeric($filter)) $filters["option"] = $filter;
+	    $where_filters = array();
+	    
 	    if (isset($filters["option"])) $where_filters[]=array($this->jffnms_class.".profile_option","=",$filters["option"]);
 
 	    return get_db_list(	array("profiles_options",$this->jffnms_class),	$ids, 	
@@ -108,7 +115,7 @@
 	$type = "";
 	//find out the type of the option
 	$query = " Select type from profiles_options where id = $option";
-	$result = db_query ($query) or die ("Query Failed - AZ10 - ".db_error());
+	$result = db_query ($query) or die ("Query Failed - profile_get_option_type() - ".db_error());
 	
 	if (db_num_rows($result) == 1) { 
 	    $row = db_fetch_array($result);
@@ -150,7 +157,7 @@
     }
 
 
-    function profile_modify_value($user_id, $option, $value) {//
+    function profile_modify_value($user_id, $option, $value) {
 
 	$value_id = 0;
 	
@@ -185,9 +192,9 @@
 	if ($value_id > 0) {
 	    $query="Update profiles set 
 		    value = '$value_id'
-		    where profile_option = $option and userid = $user_id";
+		    where profile_option = '$option' and userid = $user_id";
 	    //echo "$query\n";
-	    $result = db_query ($query) or die ("Query failed - AZ2 - ".db_error());
+	    $result = db_query ($query) or die ("Query failed - profiles_modify_value() - ".db_error());
 	    return true;
 	}
 	return false;
