@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     function rrdtool($method,$file,$opts,$force_no_module = 0) {
 	global $rrdtool_executable;
 
@@ -38,13 +42,25 @@
             if (is_array($opts)) $aux = join($opts," ");
                 else $aux = $opts;
 
+	    $use_pipe = false;
+    
             if (get_config_option("os_type")=="windows")
-                $command = "$rrdtool_executable $method \"$file\" $aux";
-            else
-                $command = "$rrdtool_executable $method '$file' $aux";
+                $command = $rrdtool_executable." ".$method." \"".$file."\" ".$aux;
+            else {
+                $command = $rrdtool_executable." ".$method." '".$file."' ".$aux;
 
+		//Check if we can use the new Piped/Managed RRDTool method
+		if (!isset($GLOBALS["rrdtool_not_use_pipe"]) && function_exists("proc_open")) 
+		    $use_pipe = true;
+	    }
+	    
 	    //debug($command);
-	    exec($command,$ret1,$ret2);
+	    	
+	    if ($use_pipe)
+		list ($ret1, $ret2) = rrd_pipe($method." '".$file."' ".$aux);
+	    else
+	        exec($command,$ret1,$ret2);
+		
 	    //debug($ret1);
 	    //debug($ret2);
 	    	    
@@ -120,7 +136,11 @@
     }
 
     function rrdtool_create($file,$opts) {
-	return rrdtool("create",$file,$opts);
+
+	if ($result = rrdtool("create", $file, $opts) && (get_config_option("os_type")=="unix")) 
+	    chmod ($file, 0660);
+	    
+	return $result;
     }
 
     function rrdtool_dump($file,$to) {
@@ -144,52 +164,72 @@
 	    $rrd_path = get_config_option("rrd_real_path");
 	    
 	    foreach ($interface_data as $int_id=>$aux1) 
-    		$interface_data[$int_id]["filename"] = "$rrd_path/interface-".$int_id.".rrd";
+    		$interface_data[$int_id]["filename"] = $rrd_path."/interface-".$int_id.".rrd";
 	    
 	    if (count($interface_data)==1) $interface_data=current($interface_data);
 	    $function_data=$interface_data;
 	    $function_data["id"]=$id;
 
-	    $less_time = (7*60);
+	    $title = str_replace("'","",$title);	// ' fix
+
 	    $start = $graph_time_start;
-	    $end = $graph_time_stop - $less_time;
+	    $end = $graph_time_stop;
+
+	    if ($end==0) $end -= (7*60);	//if it was 0, then substract 7 minutes to be sure there's data
+
+	    //debug ($graph_time_stop." = ".date("Y-m-d H:i:s", $graph_time_stop));
+	    //debug ($end." = ".date("Y-m-d H:i:s", $end));
+	    
+	    //This is only used for N Percentile calculation
+	    if ($aux == "get_graph_data")  		//if we were asked for the extra data (Export to CSV data points)
+		$function_data["other_data"] = $aux;	//pass the request to the graph (traffic.inc.php)
+
+	    $function_data["rrd_grapher_time_start"] = $start;
+	    $function_data["rrd_grapher_time_stop"] = $end;
 	    
 	    $opts_header = array( 
 		"--imgformat=PNG",
-	    	"--start=$start",
-		"--end=$end",
+	    	"--start=".$start,
+		"--end=".$end,
     		"--base=1000",
 		"--lower-limit=1",
-		"--title='$title'",
+		"--title='".$title."'",
 		"--alt-autoscale-max", 
 		"--color=GRID#CCCCCC",
 		"--color=MGRID#777777",
-		"--height=$sizey",
-		"--width=$sizex"
+		"--height=".$sizey,
+		"--width=".$sizex
 	    );
 
-    	    $real_function = "graph_$graph_function";
-	    $function_file = get_config_option("jffnms_real_path")."/engine/graphs/$graph_function.inc.php";
+    	    $real_function = "graph_".$graph_function;
+	    $function_file = get_config_option("jffnms_real_path")."/engine/graphs/".$graph_function.".inc.php";
+
 	    if (in_array($function_file,get_included_files()) || (file_exists($function_file) &&  (include_once($function_file))) ) {
 	
-		if (function_exists($real_function)) {
-		    list($graph_header, $graph_definition) = call_user_func_array($real_function,array($function_data));
-		} else logger("ERROR: Calling Function '$real_function' doesn't exists.<br>\n");
-	    } else logger ("ERROR Loading file $function_file.<br>\n");
+		if (function_exists($real_function))
+		    list($graph_header, $graph_definition, $other_data) = call_user_func_array($real_function,array($function_data));
+		else 
+		    logger("ERROR: Calling Function '$real_function' doesn't exists.<br>\n");
+	    } else 
+		logger ("ERROR Loading file $function_file.<br>\n");
 
-	    if ($aux=="MINI") { $aux = @array_merge($opts_header,array("--no-legend","--alt-y-mrtg")); }
-		else $aux = @array_merge($opts_header,$graph_header);
-
-	    $opts = @array_merge($aux,$graph_definition);
-	    //debug ($opts);
+	    
+	    $opts = @array_merge(
+			$opts_header,
+			(($aux=="MINI")
+			    ?array("--no-legend","--alt-y-mrtg")
+			    :$graph_header),
+			$graph_definition);
 	    
 	    $graph_filename = get_config_option ("engine_temp_path")."/".uniqid("").".dat"; //generate random graph filename
 	    
 	    $ret = rrdtool_graph($graph_filename, $opts);
-	    //debug ($ret);
 	    
 	    if (($aux!="MINI") && ($ret!=FALSE)) rrdtool_add_legend($graph_filename);
 
+	    if ($aux != "get_graph_data") 	//if we were not asked for the extra data (currently 95 percentile data points)
+		unset ($other_data);		// do not return it.
+
 	    if (file_exists($graph_filename)===TRUE) { //read the File
 		$fp = fopen($graph_filename,"rb");
 		$graph_data = fread($fp,filesize($graph_filename));
@@ -198,7 +238,7 @@
 		$graph_data = base64_encode ($graph_data);
 	    }
 	    
-	    return array($ret,$graph_data);
+	    return array($ret, $graph_data, $other_data);
 	}
     }
     
@@ -253,8 +293,8 @@
 		if (file_exists($file_ds)===TRUE) {
 		    $ret = rrdtool_fetch($file_ds, $opts);
 		    for ($i = 0; $i < count($ret["data"])-1;$i+=$ret["ds_cnt"])
-			if (isset($ret["data"][$i+$dsn]))
-			    $values[$dsname][]=round((int)($ret["data"][$i+$dsn]),2);
+			if (isset($ret["data"][$i]))
+			    $values[$dsname][]=round((int)($ret["data"][$i]),2);
 		}
 	    }	    
 	}
@@ -382,4 +422,28 @@
         return $ret;
     }
 
+    function rrd_pipe ($command) {
+	if (!is_array($GLOBALS["rrd_pipe"])) {
+	    $GLOBALS["rrd_pipe"]["resource"] = 
+		proc_open(get_config_option("rrdtool_executable"). " -", 
+		    array(0=> array("pipe","r"), 1=>array("pipe","w")), $GLOBALS["rrd_pipe"]["pipe"]);
+	    $GLOBALS["gc_save_vars"]["rrd_pipe"]=true;
+	}
+	
+	fwrite($GLOBALS["rrd_pipe"]["pipe"][0], $command."\n");
+	
+	stream_set_blocking($GLOBALS["rrd_pipe"]["pipe"][1], false);
+
+	while (($ret1!==false) || empty($ret)) {
+	    usleep(10);
+	    $ret1 = fgets($GLOBALS["rrd_pipe"]["pipe"][1]);
+
+	    if ($ret1!=false) $ret[] = rtrim($ret1,"\n");
+	}
+	
+	unset ($ret[count($ret)-1]); 
+	
+	//echo "<PRE>RRD: ".substr($command,0)." => ".vd($ret)."</PRE>\n";
+	return array($ret, 1);
+    }	
 ?>
