@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
 
 //CLASS 
 //-----------------------------------------
@@ -59,12 +63,12 @@
     function action_execute ($command, $parameters, $user_ids, $data_type, $data) {
         $real_function = "action_$command";
         $function_file = get_config_option("jffnms_real_path")."/engine/actions/$command.inc.php";
-	
+
 	if (!is_array($user_ids)) $user_ids=array($user_ids);
 
         if (in_array($function_file,get_included_files()) || (file_exists($function_file) &&  (@include_once($function_file))) ) {
 	    if (function_exists($real_function)) {
-	
+
 		unset($parameters_array);
 		unset($function_data);
 		
@@ -78,7 +82,7 @@
 		    
 		    $function_data[alarm]=$data; //alarm data
 		}
-		
+
 		if ($data_type=="event") {
 		    $function_data[event][]=$data;
 		    
@@ -87,10 +91,13 @@
 		}
 		
 		$param_aux = explode(",",$parameters);
-		
+
 		foreach ($param_aux as $aux) 
 		    if ($aux) {
 			$pair = explode(":",$aux);
+			
+			if ($pair[0]=="from") $parameters_array[$pair[0]]=""; //EXCEPTION "from" handling, keep the last one
+			
 			$parameters_array[$pair[0]].=" ".$pair[1];
 			$parameters_array[$pair[0]] = trim($parameters_array[$pair[0]]);
 		    }
@@ -103,7 +110,8 @@
 
 			    if ($aux=="event") $data=current($function_data[$aux]); //take only last event
 				else $data = $function_data[$aux];
-
+    
+			    if (is_array($data))
 			    foreach ($data as $var_key=>$var_data) //every piece of data
 				foreach ($parameters_array as $key=>$param)  //every parameter
 				    $parameters_array[$key]=str_replace("<$aux-$var_key>",$var_data,$parameters_array[$key]);
